summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorMorris Jobke <hey@morrisjobke.de>2017-09-20 16:04:51 +0200
committerGitHub <noreply@github.com>2017-09-20 16:04:51 +0200
commite8d80ed071650bb99eb44df55c7a0f60b23d0cdc (patch)
tree130a55d5024145e63f3777c63c2af0db5148089d /lib
parente43400eddbfdac765c8dcc5d90b4398e304dbaaf (diff)
parent388376c077975b3c0ccf8d15d8288cb343510d07 (diff)
downloadnextcloud-server-e8d80ed071650bb99eb44df55c7a0f60b23d0cdc.tar.gz
nextcloud-server-e8d80ed071650bb99eb44df55c7a0f60b23d0cdc.zip
Merge pull request #6571 from nextcloud/cachefactory-local-locking
expose local and locking memcaches trough public interfaces
Diffstat (limited to 'lib')
-rw-r--r--lib/public/ICacheFactory.php30
1 files changed, 29 insertions, 1 deletions
diff --git a/lib/public/ICacheFactory.php b/lib/public/ICacheFactory.php
index 717fbc5e627..cc4d8fa3ec3 100644
--- a/lib/public/ICacheFactory.php
+++ b/lib/public/ICacheFactory.php
@@ -31,13 +31,14 @@ namespace OCP;
*/
interface ICacheFactory{
/**
* Get a memory cache instance
*
* All entries added trough the cache instance will be namespaced by $prefix to prevent collisions between apps
*
* @param string $prefix
* @return \OCP\ICache
* @since 7.0.0
+ * @deprecated 13.0.0 Use either createLocking, createDistributed or createLocal
*/
public function create($prefix = '');
@@ -48,4 +49,31 @@ interface ICacheFactory{
* @since 7.0.0
*/
public function isAvailable();
+
+ /**
+ * create a cache instance for storing locks
+ *
+ * @param string $prefix
+ * @return \OCP\IMemcache
+ * @since 13.0.0
+ */
+ public function createLocking($prefix = '');
+
+ /**
+ * create a distributed cache instance
+ *
+ * @param string $prefix
+ * @return \OCP\ICache
+ * @since 13.0.0
+ */
+ public function createDistributed($prefix = '');
+
+ /**
+ * create a local cache instance
+ *
+ * @param string $prefix
+ * @return \OCP\ICache
+ * @since 13.0.0
+ */
+ public function createLocal($prefix = '');
}
@@ -31,13 +31,14 @@ namespace OCP;
interface ICacheFactory{
/**
- * Get a memory cache instance
+ * Get a distributed memory cache instance
*
* All entries added trough the cache instance will be namespaced by $prefix to prevent collisions between apps